@@ -745,11 +745,14 @@ function(node, types, namespaceDefs = list(), targetNamespace = NA, elementFormD
     stop("Handle this case in getType for ", xmlName(node))
 }
 
-getElementName =
+setGeneric("getElementName",
   #
   # Handles an <element name="..."> and <element ref="...">
   #
-function(node)
+function(node, keepNS = FALSE, ...)
+      standardGeneric("getElementName"))
+
+if(FALSE) {
 {
    ans = xmlGetAttr(x, "name")
    if(length(ans))
@@ -765,19 +768,30 @@ function(node)
 
    NA
 }
+}
 
-getElementName =
+setMethod("getElementName", "ANY",
   #
   # And defined differently again!!!
   #
-function(node, keepNS = FALSE)
+function(node, keepNS = FALSE, ...)
 {  
-  ans = xmlGetAttr(node, "name", xmlGetAttr(node, "ref", as.character(NA)))
+  ans = xmlGetAttr(node, "name", xmlGetAttr(node, "ref", if(xmlName(node) == "any") "any" else as.character(NA)))
   if(keepNS)
     ans
   else
     gsub(".*:", "", ans)
-}
+})
+
+setMethod("getElementName", "AnySOAPType",
+  #
+  # And defined differently again!!!
+  #
+function(node, keepNS = FALSE, ...)
+  "any"
+)
+
+
 
 asCount =
 function(x)
@@ -906,14 +920,15 @@ processSchemaElement =
 function(element, name = xmlGetAttr(element, "name"), namespaceDefs = list(), types = NULL,
                    targetNamespace = NA, elementFormDefault = NA, localElements = FALSE)
 {
-  defaultValue = xmlGetAttr(element, "default", NA_character_)
+  defaultValue = xmlGetAttr(element, "default", NA_character_) #XXX Immediate character()  
   attrs = xmlAttrs(element)
+#if(is.na(defaultValue)) browser()
   
   if(all(c("name", "type") %in% names(attrs)))  {
            #XXX test this instead of the remainder of the if() body
            #XXX need to process additional attributes such as nillable="true"
       ans = getElementRef(xmlGetAttr(element, "type"), element, types, namespaceDefs, targetNamespace, localElements)
-      ans@default = defaultValue
+      ans@default = optionalDefaultValue(ans, defaultValue)
       return(ans)
 
 
@@ -932,14 +947,14 @@ function(element, name = xmlGetAttr(element, "name"), namespaceDefs = list(), ty
    }
 
     ans = new("SimpleElement", name = attrs["name"], type = ty, nsuri = uri)
-    ans@default = defaultValue
+    ans@default = optionalDefaultValue(ans, defaultValue)
       
     return(ans)
   }
 
   if(!is.null(ref <- xmlGetAttr(element, "ref"))) {
       ans = getElementRef(ref, element, types, namespaceDefs, targetNamespace, localElements)
-      ans@default = defaultValue
+      ans@default = optionalDefaultValue(ans, defaultValue)
       return(ans)
   }
 
@@ -997,11 +1012,37 @@ function(element, name = xmlGetAttr(element, "name"), namespaceDefs = list(), ty
      obj@nsuri = as.character(targetNamespace)
 
   if(!is.null(defaultValue))
-      obj@default = defaultValue  
+      obj@default = defaultValue
+
+   obj@default = optionalDefaultValue(obj)
+
   
   obj
 }
 
+optionalDefaultValue =
+function(obj, default = obj@default)
+{
+#XXX
+ # return(default)
+#if(obj@name == "User.Request.RequestFlags") browser()
+
+
+   if(is(obj, "ClassDefinition") && typeof(default) %in% c("integer", "logical", "character", "numeric"))
+      return(NULL)
+  
+  if(is(obj, "Element"))
+    return(optionalDefaultValue(obj@type, default))
+
+  if(is(obj, "SOAPType") && length(obj@count) > 0 && 0 %in% obj@count) {
+     if(is(obj, "SimpleSequenceType"))
+         NULL
+     else
+        vector(class(default), 0)
+  } else
+     default
+}
+
 
 getElementRef =
 function(id, node, types = NULL, namespaceDefs = list(), targetNamespace = NA, localElements = FALSE)
